@@ -1,6 +1,6 @@
 from CyvoreOS.Plugins.virusTotal_plugin import run_check
 from CyvoreOS.Plugins.abuseIPDB_plugin import run_check
-#from CyvoreOS.interfaces import right_click_install
-#from CyvoreOS.Utils import CheckImpersonation
+from CyvoreOS.Plugins.whois_plugin import run_check
+from CyvoreOS.Plugins.cryptoWalletValidator_plugin import run_check
 from CyvoreOS import checkObject
 from CyvoreOS.Scan import listplugins, scanstring
\ No newline at end of file
